@@ -155,6 +155,28 @@ public:
      */
     bool resultFoundEnabled() const;
 
+    /**
+     * @brief Enables or disables the addition of detailed information to search results.
+     * 
+     * When enabled, search results will include additional metadata such as file size,
+     * modification time, file type, etc. When disabled, only the basic path information
+     * is included, which improves performance and reduces memory usage.
+     *
+     * This is separate from resultFoundEnabled() which controls whether result signals
+     * are emitted during the search process.
+     *
+     * @param enable Set @c true to include detailed information in results, @c false for basic results only.
+     */
+    void setDetailedResultsEnabled(bool enable);
+
+    /**
+     * @brief Returns whether search results include detailed information.
+     *
+     * @return @c true if search results include detailed metadata, @c false if results
+     * only contain basic path information.
+     */
+    bool detailedResultsEnabled() const;
+
     /**
      * @brief Sets the synchronization search timeout period in seconds.
      *
@@ -175,6 +197,27 @@ public:
      */
     int syncSearchTimeout() const;
 
+    /**
+     * @brief Sets the batch processing time interval in milliseconds.
+     *
+     * This controls how frequently search results are batched and emitted during
+     * asynchronous search operations. A larger interval reduces the frequency of
+     * signal emissions but may make the UI feel less responsive. A smaller interval
+     * provides more responsive updates but may impact performance with high result volumes.
+     *
+     * @param milliseconds Batch time interval in milliseconds (minimum 50, maximum 5000)
+     * @sa batchTime()
+     */
+    void setBatchTime(int milliseconds);
+
+    /**
+     * @brief Returns the current batch processing time interval in milliseconds.
+     *
+     * @return Batch time interval in milliseconds (default is 1000)
+     * @sa setBatchTime()
+     */
+    int batchTime() const;
+
 private:
     std::unique_ptr<SearchOptionsData> d;   // PIMPL
 };
