@@ -18,6 +18,8 @@
 
 #include "3rdparty/fulltext/chineseanalyzer.h"
 #include "utils/contenthighlighter.h"
+#include "utils/lucenequeryutils.h"
+#include "utils/searchutility.h"
 
 using namespace Lucene;
 
@@ -56,7 +58,7 @@ void ContentIndexedStrategy::search(const SearchQuery &query)
     }
 }
 
-Lucene::QueryPtr ContentIndexedStrategy::buildLuceneQuery(const SearchQuery &query, const Lucene::AnalyzerPtr &analyzer)
+Lucene::QueryPtr ContentIndexedStrategy::buildLuceneQuery(const SearchQuery &query, const Lucene::AnalyzerPtr &analyzer, const QString &searchPath)
 {
     try {
         m_keywords.clear();
@@ -68,29 +70,44 @@ Lucene::QueryPtr ContentIndexedStrategy::buildLuceneQuery(const SearchQuery &que
                 L"contents",
                 analyzer);
 
+        Lucene::QueryPtr mainQuery;
         if (query.type() == SearchQuery::Type::Simple) {
-            return buildSimpleContentsQuery(query, contentsParser);
+            mainQuery = buildSimpleContentsQuery(query, contentsParser);
         } else if (query.type() == SearchQuery::Type::Boolean) {
             if (query.subQueries().isEmpty()) {
                 // For an empty boolean query, match nothing.
-                return newLucene<Lucene::BooleanQuery>();
-            }
-
-            // Determine which logic path to take for boolean queries
-            if (mixedAndEnabled && query.booleanOperator() == SearchQuery::BooleanOperator::AND) {
-                // New "advanced" AND logic for contents/filename
-                return buildAdvancedAndQuery(query, contentsParser, analyzer);
+                mainQuery = newLucene<Lucene::BooleanQuery>();
             } else {
-                // "Standard" contents-only logic for:
-                // 1. OR queries (regardless of mixedAndEnabled value).
-                // 2. AND queries when mixedAndEnabled is false.
-                return buildStandardBooleanContentsQuery(query, contentsParser);
+                // Determine which logic path to take for boolean queries
+                if (mixedAndEnabled && query.booleanOperator() == SearchQuery::BooleanOperator::AND) {
+                    // New "advanced" AND logic for contents/filename
+                    mainQuery = buildAdvancedAndQuery(query, contentsParser, analyzer);
+                } else {
+                    // "Standard" contents-only logic for:
+                    // 1. OR queries (regardless of mixedAndEnabled value).
+                    // 2. AND queries when mixedAndEnabled is false.
+                    mainQuery = buildStandardBooleanContentsQuery(query, contentsParser);
+                }
             }
         } else {
             qWarning() << "Unknown SearchQuery type encountered.";
-            return newLucene<Lucene::BooleanQuery>();   // Should not happen
+            mainQuery = newLucene<Lucene::BooleanQuery>();   // Should not happen
         }
 
+        // Add path prefix query optimization
+        if (mainQuery && SearchUtility::shouldUsePathPrefixQuery(searchPath)) {
+            QueryPtr pathPrefixQuery = LuceneQueryUtils::buildPathPrefixQuery(searchPath, "path");
+            if (pathPrefixQuery) {
+                BooleanQueryPtr finalQuery = newLucene<BooleanQuery>();
+                finalQuery->add(mainQuery, BooleanClause::MUST);
+                finalQuery->add(pathPrefixQuery, BooleanClause::MUST);
+                qInfo() << "Using path prefix query for content search optimization:" << searchPath;
+                return finalQuery;
+            }
+        }
+
+        return mainQuery;
+
     } catch (const Lucene::LuceneException &e) {
         qWarning() << "Error building Lucene query:" << QString::fromStdWString(e.getError());
         return nullptr;
@@ -111,19 +128,21 @@ QueryPtr ContentIndexedStrategy::buildAdvancedAndQuery(const SearchQuery &query,
 
     Lucene::BooleanQueryPtr overallQuery = newLucene<Lucene::BooleanQuery>();
     Lucene::BooleanQueryPtr mainAndClausesQuery = newLucene<Lucene::BooleanQuery>();
+    Lucene::BooleanQueryPtr allContentsQuery = newLucene<Lucene::BooleanQuery>();
     Lucene::BooleanQueryPtr allFilenamesQuery = newLucene<Lucene::BooleanQuery>();
     bool hasValidKeywords = false;
 
     for (const auto &subQuery : query.subQueries()) {
         m_keywords.append(subQuery.keyword());
-        std::wstring keywordStd = subQuery.keyword().toStdWString();
-        if (keywordStd.empty()) {
+        if (subQuery.keyword().isEmpty()) {
             continue;   // Skip empty keywords
         }
         hasValidKeywords = true;
 
-        Lucene::QueryPtr contentsTermQuery = contentsParser->parse(keywordStd);
-        Lucene::QueryPtr filenameTermQuery = filenameParser->parse(keywordStd);
+        // 使用 LuceneQueryUtils 处理特殊字符
+        Lucene::String processedKeyword = LuceneQueryUtils::processQueryString(subQuery.keyword(), false);
+        Lucene::QueryPtr contentsTermQuery = contentsParser->parse(processedKeyword);
+        Lucene::QueryPtr filenameTermQuery = filenameParser->parse(processedKeyword);
 
         // Build (contents:keyword OR filename:keyword)
         Lucene::BooleanQueryPtr combinedTermQuery = newLucene<Lucene::BooleanQuery>();
@@ -131,16 +150,25 @@ QueryPtr ContentIndexedStrategy::buildAdvancedAndQuery(const SearchQuery &query,
         combinedTermQuery->add(filenameTermQuery, Lucene::BooleanClause::SHOULD);
 
         mainAndClausesQuery->add(combinedTermQuery, Lucene::BooleanClause::MUST);
+        allContentsQuery->add(contentsTermQuery, Lucene::BooleanClause::MUST);
         allFilenamesQuery->add(filenameTermQuery, Lucene::BooleanClause::MUST);
     }
 
     if (!hasValidKeywords) {   // All subQuery keywords were empty
+        qWarning() << "No valid keywords found in advanced AND query";
         return newLucene<Lucene::BooleanQuery>();   // Matches nothing
     }
 
-    // Final query: ( (c:k1 OR f:k1) AND ... ) AND NOT (f:k1 AND f:k2 ...)
+    // New logic: Include results that match content OR exclude pure filename-only matches
+    // Final query: ( (c:k1 OR f:k1) AND ... ) AND NOT (f:k1 AND f:k2 ... AND NOT (c:k1 AND c:k2 ...))
+    // This means: exclude documents that match all keywords in filename but don't match all keywords in content
+    Lucene::BooleanQueryPtr pureFilenameQuery = newLucene<Lucene::BooleanQuery>();
+    pureFilenameQuery->add(allFilenamesQuery, Lucene::BooleanClause::MUST);
+    pureFilenameQuery->add(allContentsQuery, Lucene::BooleanClause::MUST_NOT);
+    
     overallQuery->add(mainAndClausesQuery, Lucene::BooleanClause::MUST);
-    overallQuery->add(allFilenamesQuery, Lucene::BooleanClause::MUST_NOT);
+    overallQuery->add(pureFilenameQuery, Lucene::BooleanClause::MUST_NOT);
+    
     return overallQuery;
 }
 
@@ -151,12 +179,12 @@ QueryPtr ContentIndexedStrategy::buildStandardBooleanContentsQuery(const SearchQ
 
     for (const auto &subQuery : query.subQueries()) {
         m_keywords.append(subQuery.keyword());
-        std::wstring keywordStd = subQuery.keyword().toStdWString();
-        if (keywordStd.empty()) {
+        if (subQuery.keyword().isEmpty()) {
             continue;   // Skip empty keywords
         }
 
-        Lucene::QueryPtr termQuery = contentsParser->parse(keywordStd);
+        // 使用 LuceneQueryUtils 处理特殊字符
+        Lucene::QueryPtr termQuery = contentsParser->parse(LuceneQueryUtils::processQueryString(subQuery.keyword(), false));
         booleanQuery->add(termQuery,
                           query.booleanOperator() == SearchQuery::BooleanOperator::AND ? Lucene::BooleanClause::MUST : Lucene::BooleanClause::SHOULD);
     }
@@ -170,7 +198,8 @@ QueryPtr ContentIndexedStrategy::buildSimpleContentsQuery(const SearchQuery &que
     if (query.keyword().isEmpty()) {
         return newLucene<Lucene::BooleanQuery>();   // Match nothing for empty keyword
     }
-    return contentsParser->parse(query.keyword().toStdWString());
+    // 使用 LuceneQueryUtils 处理特殊字符
+    return contentsParser->parse(LuceneQueryUtils::processQueryString(query.keyword(), false));
 }
 
 void ContentIndexedStrategy::processSearchResults(const Lucene::IndexSearcherPtr &searcher,
@@ -197,8 +226,47 @@ void ContentIndexedStrategy::processSearchResults(const Lucene::IndexSearcherPtr
 
         try {
             Lucene::ScoreDocPtr scoreDoc = scoreDocs[i];
-            Lucene::DocumentPtr doc = searcher->doc(scoreDoc->doc);
-            QString path = QString::fromStdWString(doc->get(L"path"));
+            if (!scoreDoc) {
+                qWarning() << "Null ScoreDoc encountered at index" << i;
+                continue;
+            }
+
+            // Defensive check: verify document ID is valid
+            if (scoreDoc->doc < 0) {
+                qWarning() << "Invalid document ID:" << scoreDoc->doc;
+                continue;
+            }
+
+            // Safely retrieve document (could throw if index is corrupted)
+            Lucene::DocumentPtr doc;
+            try {
+                doc = searcher->doc(scoreDoc->doc);
+                if (!doc) {
+                    qWarning() << "Failed to retrieve document at index:" << scoreDoc->doc;
+                    continue;
+                }
+            } catch (const Lucene::LuceneException &e) {
+                qWarning() << "Exception while retrieving document:" << QString::fromStdWString(e.getError());
+                continue;
+            } catch (const std::exception &e) {
+                qWarning() << "Standard exception while retrieving document:" << e.what();
+                continue;
+            }
+
+            // Safely get path
+            Lucene::String pathField;
+            try {
+                pathField = doc->get(L"path");
+                if (pathField.empty()) {
+                    qWarning() << "Document missing path field at index:" << scoreDoc->doc;
+                    continue;
+                }
+            } catch (const std::exception &e) {
+                qWarning() << "Exception retrieving path field:" << e.what();
+                continue;
+            }
+
+            QString path = QString::fromStdWString(pathField);
 
             if (!path.startsWith(searchPath)) {
                 continue;
@@ -209,9 +277,17 @@ void ContentIndexedStrategy::processSearchResults(const Lucene::IndexSearcherPtr
                 continue;
             }
 
+            // Safely check hidden status
             if (Q_LIKELY(!m_options.includeHidden())) {
-                if (QString::fromStdWString(doc->get(L"is_hidden")).toLower() == "y")
-                    continue;
+                try {
+                    Lucene::String hiddenField = doc->get(L"is_hidden");
+                    if (!hiddenField.empty() && QString::fromStdWString(hiddenField).toLower() == "y") {
+                        continue;
+                    }
+                } catch (const std::exception &e) {
+                    qWarning() << "Exception retrieving is_hidden field:" << e.what();
+                    // Default to visible if field can't be read
+                }
             }
 
             // 创建搜索结果
@@ -222,10 +298,23 @@ void ContentIndexedStrategy::processSearchResults(const Lucene::IndexSearcherPtr
 
             // 使用ContentHighlighter命名空间进行高亮
             if (enableRetrieval) {
-                const QString &content = QString::fromStdWString(doc->get(L"contents"));
-                const QString &highlightedContent = ContentHighlighter::customHighlight(m_keywords, content, previewLen, enableHTML);
-                resultApi.setHighlightedContent(highlightedContent);
+                try {
+                    // Safely get contents with null check
+                    Lucene::String contentField = doc->get(L"contents");
+                    if (!contentField.empty()) {
+                        const QString content = QString::fromStdWString(contentField);
+                        const QString highlightedContent = ContentHighlighter::customHighlight(m_keywords, content, previewLen, enableHTML);
+                        resultApi.setHighlightedContent(highlightedContent);
+                    }
+                } catch (const Lucene::LuceneException &e) {
+                    qWarning() << "Exception retrieving content field:" << QString::fromStdWString(e.getError());
+                    // Continue without content highlight
+                } catch (const std::exception &e) {
+                    qWarning() << "Standard exception retrieving content field:" << e.what();
+                    // Continue without content highlight
+                }
             }
+
             // 添加到结果集合
             m_results.append(result);
 
@@ -236,6 +325,12 @@ void ContentIndexedStrategy::processSearchResults(const Lucene::IndexSearcherPtr
         } catch (const Lucene::LuceneException &e) {
             qWarning() << "Error processing result:" << QString::fromStdWString(e.getError());
             continue;
+        } catch (const std::exception &e) {
+            qWarning() << "Standard exception:" << e.what();
+            continue;
+        } catch (...) {
+            qWarning() << "Unknown exception during result processing";
+            continue;
         }
     }
 
@@ -269,7 +364,7 @@ void ContentIndexedStrategy::performContentSearch(const SearchQuery &query)
         AnalyzerPtr analyzer = newLucene<ChineseAnalyzer>();
 
         // 构建查询
-        m_currentQuery = buildLuceneQuery(query, analyzer);
+        m_currentQuery = buildLuceneQuery(query, analyzer, m_options.searchPath());
         if (!m_currentQuery) {
             qWarning() << "Failed to build Lucene query";
             emit errorOccurred(SearchError(ContentSearchErrorCode::ContentIndexException));
