@@ -11,7 +11,7 @@
 DFM_SEARCH_BEGIN_NS
 DCORE_USE_NAMESPACE
 
-constexpr int kDefaultBatchTime = 100;   // 100ms
+constexpr int kDefaultBatchTime = 1000;   // 1000ms
 
 GenericSearchEngine::GenericSearchEngine(QObject *parent)
     : AbstractSearchEngine(parent),
@@ -72,6 +72,9 @@ SearchOptions GenericSearchEngine::searchOptions() const
 void GenericSearchEngine::setSearchOptions(const SearchOptions &options)
 {
     m_options = options;
+    
+    // 更新批处理定时器间隔
+    m_batchTimer.setInterval(m_options.batchTime());
 }
 
 SearchStatus GenericSearchEngine::status() const
@@ -93,6 +96,7 @@ void GenericSearchEngine::search(const SearchQuery &query)
 
     // 清空批处理结果并启动定时器
     m_batchResults.clear();
+    m_batchTimer.setInterval(m_options.batchTime());
     m_batchTimer.start();
 
     // 保存当前查询
@@ -116,37 +120,8 @@ void GenericSearchEngine::search(const SearchQuery &query)
 void GenericSearchEngine::searchWithCallback(const SearchQuery &query,
                                              SearchEngine::ResultCallback callback)
 {
-    if (m_status.load() == SearchStatus::Searching)
-        return;
-
-    m_cancelled.store(false);
-    setStatus(SearchStatus::Searching);
-    emit searchStarted();
-
-    // 清空结果列表
-    m_results.clear();
-
-    // 清空批处理结果并启动定时器
-    m_batchResults.clear();
-    m_batchTimer.start();
-
-    // 保存当前查询和回调
-    m_currentQuery = query;
     m_callback = callback;
-
-    // 验证搜索条件
-    auto validationResult = validateSearchConditions();
-    if (validationResult.isError()) {
-        reportError(validationResult);
-        setStatus(SearchStatus::Error);
-        return;
-    }
-
-    // 执行异步搜索
-    QMetaObject::invokeMethod(m_worker, "doSearch",
-                              Q_ARG(DFMSEARCH::SearchQuery, query),
-                              Q_ARG(DFMSEARCH::SearchOptions, m_options),
-                              Q_ARG(DFMSEARCH::SearchType, searchType()));
+    searchSync(query);
 }
 
 SearchResultExpected GenericSearchEngine::searchSync(const SearchQuery &query)
@@ -185,6 +160,15 @@ void GenericSearchEngine::handleSearchResult(const DFMSEARCH::SearchResult &resu
     // 存储结果到全局结果列表
     m_results.append(result);
 
+    // 如果设置了回调，立即调用回调，如果回调返回true则终止搜索
+    if (m_callback) {
+        if (m_callback(result)) {
+            // 回调返回 true，取消搜索
+            cancel();
+            return;
+        }
+    }
+
     // 将结果添加到批处理队列
     m_batchResults.append(result);
 }
@@ -208,13 +192,8 @@ void GenericSearchEngine::handleSearchFinished(const DFMSEARCH::SearchResultList
     // 设置状态为完成
     setStatus(SearchStatus::Finished);
 
-    // TODO (search): perf
-    // 如果设置了回调，调用回调
-    if (m_callback) {
-        std::for_each(results.begin(), results.end(), [this](const SearchResult &result) {
-            m_callback(result);
-        });
-    }
+    // 如果没有通过 handleSearchResult 中断搜索，在这里执行最终检查
+    // 注意：通常在 handleSearchResult 已处理大部分情况，此处仅作为备用
     // 发送完成信号
     emit searchFinished(m_results);
 }
@@ -284,7 +263,8 @@ SearchResultExpected GenericSearchEngine::doSyncSearch(const SearchQuery &query)
 
 SearchError GenericSearchEngine::validateSearchConditions()
 {
-    if (m_currentQuery.type() == SearchQuery::Type::Simple) {
+    if (m_currentQuery.type() == SearchQuery::Type::Simple || 
+        m_currentQuery.type() == SearchQuery::Type::Wildcard) {
         if (m_options.searchPath().isEmpty()) {
             return SearchError(SearchErrorCode::PathIsEmpty);
         }
