@@ -35,7 +35,7 @@ public:
         Boolean,   // 布尔多关键词搜索
         Pinyin,   // 拼音搜索
         FileType,   // 文件类型搜索
-        FileExt,    // 文件后缀搜索
+        FileExt,   // 文件后缀搜索
         Combined   // 组合搜索(关键词+文件类型/拼音/文件后缀)
     };
 
@@ -50,7 +50,7 @@ public:
         bool usePinyin = false;
         SearchQuery::BooleanOperator booleanOp = SearchQuery::BooleanOperator::AND;
         bool combineWithFileType = false;   // 是否与文件类型组合
-        bool combineWithFileExt = false;    // 是否与文件后缀组合
+        bool combineWithFileExt = false;   // 是否与文件后缀组合
     };
 
     explicit FileNameIndexedStrategy(const SearchOptions &options, QObject *parent = nullptr);
@@ -84,7 +84,7 @@ private:
     void executeIndexQuery(const IndexQuery &query, const QString &searchPath, const QStringList &searchExcludedPaths);
 
     // 构建 Lucene 查询
-    QueryPtr buildLuceneQuery(const IndexQuery &query) const;
+    QueryPtr buildLuceneQuery(const IndexQuery &query, const QString &searchPath) const;
 
     // 构建布尔查询的辅助方法
     BooleanQueryPtr buildBooleanTermsQuery(const IndexQuery &query, const AnalyzerPtr &analyzer) const;
@@ -117,9 +117,6 @@ public:
     QueryPtr buildWildcardQuery(const QString &keyword, bool caseSensitive, const Lucene::AnalyzerPtr &analyzer) const;
     QueryPtr buildSimpleQuery(const QString &keyword, bool caseSensitive, const Lucene::AnalyzerPtr &analyzer) const;
 
-    // 处理字符串大小写
-    String processString(const QString &str, bool caseSensitive) const;
-
 private:
     // 通用的查询构建方法
     QueryPtr buildCommonQuery(const QString &keyword, bool caseSensitive, const Lucene::AnalyzerPtr &analyzer, bool allowWildcard = false) const;
