@@ -9,6 +9,7 @@
 #include <QStack>
 #include <QElapsedTimer>
 #include <QDebug>
+#include <QRegularExpression>
 
 DFM_SEARCH_BEGIN_NS
 
@@ -34,6 +35,7 @@ void FileNameRealTimeStrategy::search(const SearchQuery &query)
     // 获取文件类型过滤
     FileNameOptionsAPI optionsApi(const_cast<SearchOptions &>(m_options));
     const QStringList fileExts = optionsApi.fileExtensions();
+    const bool detailedResults = m_options.detailedResultsEnabled();
     const bool resultFoundEnabled = m_options.resultFoundEnabled();
 
     // 检查搜索路径
@@ -120,6 +122,10 @@ void FileNameRealTimeStrategy::search(const SearchQuery &query)
                 matches = fileName.contains(query.keyword(),
                                             caseSensitive ? Qt::CaseSensitive : Qt::CaseInsensitive);
             }
+            // 通配符查询模式
+            else if (query.type() == SearchQuery::Type::Wildcard) {
+                matches = matchWildcard(fileName, query.keyword(), caseSensitive);
+            }
             // 布尔查询模式
             else if (query.type() == SearchQuery::Type::Boolean) {
                 matches = matchBoolean(fileName, query, caseSensitive, false);
@@ -137,13 +143,15 @@ void FileNameRealTimeStrategy::search(const SearchQuery &query)
                 // 创建搜索结果
                 SearchResult result(info.filePath());
 
-                if (resultFoundEnabled) {
+                if (detailedResults) {
                     FileNameResultAPI api(result);
                     api.setModifiedTime(info.lastModified().toString());
                     api.setIsDirectory(info.isDir());
                     api.setFileType(info.suffix().isEmpty() ? (info.isDir() ? "directory" : "unknown") : info.suffix());
+                }
 
-                    // 实时发送结果
+                // 实时发送结果
+                if (resultFoundEnabled) {
                     emit resultFound(result);
                 }
 
@@ -211,6 +219,16 @@ bool FileNameRealTimeStrategy::matchBoolean(const QString &fileName, const Searc
     return false;
 }
 
+bool FileNameRealTimeStrategy::matchWildcard(const QString &fileName, const QString &pattern, bool caseSensitive)
+{
+    // 利用Qt内置的通配符匹配功能
+    QRegularExpression regex = QRegularExpression::fromWildcard(
+        pattern, 
+        caseSensitive ? Qt::CaseSensitive : Qt::CaseInsensitive
+    );
+    return regex.match(fileName).hasMatch();
+}
+
 void FileNameRealTimeStrategy::cancel()
 {
     m_cancelled.store(true);
